// AlphaBlend sample - Plugin for PhotoFiltre
// Copyright Antonio DA CRUZ - December 2004

unit Params;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ExtCtrls, ComCtrls;

type
  TParamsForm = class(TForm)
    BtnCancel: TButton;
    BtnOk: TButton;
    PnlColor: TPanel;
    LblColor: TLabel;
    ColorDialog: TColorDialog;
    LblTrans: TLabel;
    TrbTrans: TTrackBar;
    BtnPreview: TButton;
    BtnRestore: TButton;
    procedure BtnOkClick(Sender: TObject);
    procedure BtnCancelClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormKeyPress(Sender: TObject; var Key: Char);
    procedure PnlColorClick(Sender: TObject);
    procedure BtnPreviewClick(Sender: TObject);
    procedure BtnRestoreClick(Sender: TObject);
  private
    procedure DoAction;
  public
    DialogResult: Boolean;
  end;

var
  ParamsForm: TParamsForm;

implementation

uses
  PlgInt, Plugin;

{$R *.dfm}

type
  TRGB = packed record
    Blue, Green, Red: Byte;
  end;
  PRGB = ^TRGB;

procedure TParamsForm.FormCreate(Sender: TObject);
begin
  // translation
  if GetLanguageCode <> 'FR' then
  begin
    Caption := 'AlphaBlend effect';
    BtnCancel.Caption := 'Cancel';
    BtnPreview.Caption := 'Preview';
    BtnRestore.Caption := 'Restore';
    LblColor.Caption := 'Color :';
    LblTrans.Caption := 'Transparency :';
  end;
  ActiveControl := BtnOk;
end;

procedure TParamsForm.DoAction;
var
  Image: TPlgImage;
  Row, Col: Integer;
  ColorRGB: TRGB;
  P: PRGB;
begin
  try
    BeginFilter;

    // get the selction bitmap
    Image.piWidth := GetSelWidth;
    Image.piHeight := GetSelHeight;
    CreateDBmp(@Image);
    CheckPluginFunc(GetSelBitmap(Image.piBitmap));

    // Delphi color to RGB Color
    ColorRGB.Blue := GetBValue(PnlColor.Color);
    ColorRGB.Green := GetGValue(PnlColor.Color);
    ColorRGB.Red := GetRValue(PnlColor.Color);
    
    // fill with color
    for Row := 0 to Image.piHeight - 1 do
    begin
      P := GetScanLineDBmp(@Image, Row);
      for Col := 0 to Image.piWidth - 1 do
      begin
        P^ := ColorRGB;
        Inc(P);
      end;
    end;
    // set the result
    CheckPluginFunc(SetSelBitmap(Image.piBitmap));

    // AlphaBlend
    CheckPluginFunc(SetAlphaBlend(TrbTrans.Position));
  finally
    FreeDBmp(@Image);
    EndFilter;
  end;
end;

procedure TParamsForm.BtnPreviewClick(Sender: TObject);
begin
  DoAction;
end;

procedure TParamsForm.BtnRestoreClick(Sender: TObject);
begin
  RestoreUndoBitmap;
end;

procedure TParamsForm.BtnOkClick(Sender: TObject);
begin
  DoAction;
  DialogResult := True;
  Close;
end;

procedure TParamsForm.BtnCancelClick(Sender: TObject);
begin
  Close;
end;

// Must set KeyPreview := True
procedure TParamsForm.FormKeyPress(Sender: TObject; var Key: Char);
begin
  if Key = #27 then Close
  else if Key = #13 then BtnOkClick(Sender);
end;

procedure TParamsForm.PnlColorClick(Sender: TObject);
begin
  if ColorDialog.Execute then
    PnlColor.Color := ColorDialog.Color;
end;

end.
