// Interface de premier niveau pour le dveloppement de plugin pour PhotoFiltre

// Version 1.6 / Avril 2005 / Copyright Antonio Da Cruz
// Merci de ne pas modifier les sources sans mon autorisation !

unit PlgInt;

interface

uses
  Windows, SysUtils, Graphics, Forms;

const
  MaxLongStr = 255;
  MaxShortStr = 63;

  // type du plugin
  PT_FILTER = 0;
  PT_IMAGE = 1;
  PT_FILE_IMPORT = 2;
  PT_FILE_EXPORT = 3;
  PT_TOOL = 4;

  // mode de dialogue
  DM_MODAL = 0;
  DM_PREVIEW = 1;
  DM_COLOR_PICKER = 2;

  // flags de slection
  SF_AUTO = 0;
  SF_NONE = 1;

  // flags pour la cration d'image
  IF_CREATE = 0;
  IF_FILE = 1;

  // flags pour l'activation du menu
  MF_RGB_COLORS = $00000001;
  MF_INDEXED_COLORS = $00000002;
  MF_TRANSPARENT = $00000004;
  MF_NOT_TRANSPARENT = $00000008;
  MF_SELECTED = $00000010;
  MF_NOT_SELECTED = $00000020;
  MF_NEED_IMAGE = $00000040;
  MF_NEED_MORE_THAN_ONE_IMAGE = $00000080;
  MF_LAYERED = $00000100; // contient plus d'un calque
  MF_NOT_LAYERED = $00000200; // contient un seul calque
  MF_RGBA_COLORS = $00000400;
  MF_NOT_RGBA_COLORS = $00000800;  
  // test sur l'extension du fichier en cours
  MF_IMAGE_JPEG = $00010000;
  MF_IMAGE_GIF = $00020000;
  MF_IMAGE_PNG = $00040000;  
  MF_IMAGE_BMP = $00080000;
  MF_IMAGE_TIFF = $00100000;
  MF_IMAGE_PFS = $00200000;
  MF_JPEG_EXIF_DATA = $00400000;

  // type d'tat de l'application
  ST_MINIMIZE = 0;
  ST_RESTORE = 1;
  ST_MAXIMIZE = 2;
  ST_HIDE_FORMS = 3;
  ST_SHOW_FORMS = 4;

type
  // pour RegisterApplication
  PApplication = ^TApplication;

  // structure pour rcuprer les infos sur traduction
  PPluginLanguage = ^TPluginLanguage;
  TPluginLanguage = record
    Code: array[0..3] of Char;
    Language: array[0..MaxShortStr] of Char;
    Flags: Integer;
  end;

  // structure d'entte du plugin
  PPluginHeader = ^TPluginHeader;
  TPluginHeader = record
    Caption: array[0..MaxShortStr] of Char;
    Version: array[0..MaxShortStr] of Char;
    PluginType: Integer;
    Author: array[0..MaxShortStr] of Char;
    Comment: array[0..MaxLongStr] of Char;
    Reserved: array[0..MaxLongStr] of Char; // non utilis
    Flags: Integer; // pour l'activation du menu
  end;

  // permet d'encapsuler un objet TBitmap Delphi (compatibilit de niveau 2)
  // (structure propose par PF)
  PPlgImage = ^TPlgImage;
  TPlgImage = record
    piSize: Integer; // Taille de la structure
    piWidth: Integer; // Largeur en pixels
    piHeight: Integer; // Hauteur en pixels
    piWidthSize: Integer; // Taille X utile en octets (piWidth * piByteCount)
    piScanlineSize: Integer; // Scanline complete en octets (alignement 32 bits)
    piByteCount: Integer; // Nombre d'octets par pixels
    piDataSize: Integer; // Taille totale du buffer (piScanlineSize * piHeight)
    piBuffer: Pointer; // Adresse du buffer de travail
    piBitmap: TBitmap; // Pointeur vers un objet TBitmap Delphi
    piHandle: HBitmap; // Handle du bitmap Windows
  end;

  // types pour la structure d'xcution
  TSimpleProc = procedure; stdcall;

  TBeginFilterProc = procedure (pMsg: PChar; ChangeCursor: LongBool); stdcall;

  TGetBitmapProc = function (Bitmap: TBitmap): LongBool; stdcall;

  TSetBitmapProc = function (Bitmap: TBitmap): LongBool; stdcall;

  TSetSelBitmapProc = function (Bitmap: TBitmap;
    Flag: Integer): LongBool; stdcall;

  TGetTransparentColor = function: TColor; stdcall;

  TSetTransparentColor = function (Color: TColor): LongBool; stdcall;

  TGetInt = function: Integer; stdcall;

  TSetInt = function (Value: Integer): Integer; stdcall;

  TNewImage = function (Bitmap: TBitmap; pFileName: PChar; Flag: Integer;
    ColorCount: Integer; TransColor: TColor): LongBool; stdcall;

  TShowFormProc = procedure (Form: TForm; Mode: Integer;
    MainFormCenter, CloseWaiting: LongBool); stdcall;

  TSetAlphaBlendProc = function (Alpha: Integer): LongBool; stdcall;

  TDrawSelBorder = function (Width: Integer; Color: TColor;
    Antialias: LongBool): LongBool; stdcall;

  TGetStr = function (pBuffer: PChar; MaxSize: Integer): PChar; stdcall;

  TSetStr = function (pBuffer: PChar): LongBool; stdcall;

  TGetBitmapByName =  function (Bitmap: TBitmap;
    pFileName: PChar): LongBool; stdcall;

  TGetThumb = function (Bitmap: TBitmap; BkColor: TColor; BorderSize,
    ShadowSize: Integer; ShadowBkColor: TColor; var R: TRect): LongBool; stdcall;

  TGetThumbByName =  function (Bitmap: TBitmap; pFileName: PChar;
    BkColor: TColor; BorderSize, ShadowSize: Integer;
    ShadowBkColor: TColor; var R: TRect): LongBool; stdcall;

  TEnumImageProc = function (pFileName: PChar; Width, Height,
    NbColors: Integer; TransColor: TColor): LongBool; stdcall;

  TEnumImages = function (EnumImageProc: TEnumImageProc): LongBool; stdcall;

  TPrepareDialogProc = procedure (Handle: HWND; Mode: Integer;
    MainFormCenter, CloseWaiting: LongBool); stdcall;

  TCreateDBmpProc =  function (pImg: PPlgImage): Integer; stdcall;

  TFreeDBmpProc = function (pImg: PPlgImage): Integer; stdcall;

  TReleaseHandleDBmpProc = function (pImg: PPlgImage): HBitmap; stdcall;

  TGetScanLineDBmpProc = function (pImg: PPlgImage; Row: Integer): Pointer; stdcall;

  TResetUndoAreaProc = function (R: TRect): TRect; stdcall;

  TGetSelShape = function (Points: PPoint): Integer; stdcall;

  TDisableLayersPaintingProc = procedure (Disable: LongBool); stdcall;
  
  TGetLayerRect = function : TRect; stdcall;

  TGetLayerPos = function : TPoint; stdcall;

  // structure d'excution
  PPluginStruct = ^TPluginStruct;
  TPluginStruct = record
    MainHandle: HWND;
    ImageExists: LongBool;
    Selected: LongBool;
    SelRect: TRect;
    ImgRect: TRect;
    XP_ThemesEnabled: LongBool;
    BeginFilter: TBeginFilterProc;
    EndFilter: TSimpleProc;
    GetBitmap: TGetBitmapProc;
    SetBitmap: TSetBitmapProc;
    GetSelBitmap: TGetBitmapProc;
    SetSelBitmap: TSetSelBitmapProc;
    GetTransparentColor: TGetTransparentColor;
    SetTransparentColor: TSetTransparentColor;
    GetColorCount: TGetInt;
    SetColorCount: TSetInt;
    NewImage: TNewImage;
    ShowForm: TShowFormProc;
    SetAlphaBlend: TSetAlphaBlendProc;
    DrawSelBorder: TDrawSelBorder;
    GetSelMask: TGetBitmapProc;
    ResetSaveMenu: TSimpleProc;
    GetImgFileName: TGetStr;
    GetExePath: TGetStr;
    GetOpenPath: TGetStr;
    GetSavePath: TGetStr;
    GetPluginPath: TGetStr;
    GetIniFile: TGetStr;
    SetImgFileName: TSetStr;
    GetBitmapByName: TGetBitmapByName;
    GetThumb: TGetThumb;
    GetThumbByName: TGetThumbByName;
    EnumImages: TEnumImages;
    // compatibilit de niveau >= 2
    PrepareDialog: TPrepareDialogProc;
    CreateDBmp: TCreateDBmpProc;
    FreeDBmp: TFreeDBmpProc;
    ReleaseHandleDBmp: TReleaseHandleDBmpProc;
    GetScanlineDBmp: TGetScanlineDBmpProc;
    // compatibilit de niveau >= 3
    GetSelSelMask: TGetBitmapProc;
    GetImageDPI: TGetInt;
    SetImageDPI: TSetInt;
    SetSelMask: TSetSelBitmapProc;
    ResetUndoArea: TResetUndoAreaProc;
    SetApplicationState: TSetInt;
    GetSelShape: TGetSelShape;
    NotUsed: Pointer;
    // compatibilit de niveau >= 4 (PhotoFiltre Studio)
    GetLayerRect: TGetLayerRect;
    GetLayerBitmap: TGetBitmapProc;
    SetLayerBitmap: TSetBitmapProc;
    GetLayerAlpha: TGetBitmapProc;
    SetLayerAlpha: TSetBitmapProc;
    GetSelAlpha: TGetBitmapProc;
    SetSelAlpha: TSetBitmapProc;
    DisableLayersPainting: TDisableLayersPaintingProc;
    GetImageColorMode: TGetInt;
    GetLayerPos: TGetLayerPos;
    Reserved: array[0..9] of Pointer; // si futures fonctions
  end;

var
  // variables globales
  PluginLanguage: TPluginLanguage;
  PluginHeader: TPluginHeader;
  PluginStruct: TPluginStruct;

implementation
       
end.
 