unit Params;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls;

type
  TParamsForm = class(TForm)
    BtnCancel: TButton;
    BtnOk: TButton;
    BtnPreview: TButton;
    RdbRBG: TRadioButton;
    RdbGRB: TRadioButton;
    RdbGBR: TRadioButton;
    RdbBRG: TRadioButton;
    RdbBGR: TRadioButton;
    ChkPreview: TCheckBox;
    procedure BtnOkClick(Sender: TObject);
    procedure BtnCancelClick(Sender: TObject);
    procedure BtnPreviewClick(Sender: TObject);
    procedure RdbClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ChkPreviewClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure FormKeyPress(Sender: TObject; var Key: Char);
  private
    Bitmap: TBitmap;
    Changed, Preview: Boolean;
    function DoPreview: Boolean;
    procedure DoAction;
    procedure SwapBitmap;
    procedure SwapRGB(var RGB: TRGBTriple; Index: Integer);
    function CheckSwap: Integer;
  public
    DialogResult: Boolean;
  end;

var
  ParamsForm: TParamsForm;

implementation

uses
  Plugin;

{$R *.dfm}

procedure TParamsForm.FormCreate(Sender: TObject);
begin
  // initialisation
  ActiveControl := BtnOk;
  DialogResult := False;
  // prpare le bitmap pour rcuprer la slection
  Bitmap := TBitmap.Create;
  Bitmap.PixelFormat := pf24bit;
  Bitmap.Width := GetSelWidth;
  Bitmap.Height := GetSelHeight;
end;

procedure TParamsForm.FormDestroy(Sender: TObject);
begin
  Bitmap.Free;
end;

procedure TParamsForm.FormShow(Sender: TObject);
begin
  RdbRBG.Checked := True;
end;

// Cration de l'aperu en appliquant le filtre
function TParamsForm.DoPreview: Boolean;
begin
  try
    DoAction;
    Preview := True;
    Changed := False;
    Result := True;
  except
    Result := False;
    ShowPluginErrorMsg;
  end;
end;

// Application du filtre
procedure TParamsForm.DoAction;
begin
  try
    BeginFilter;
    // restaure si ncessaire
    if Preview then RestoreUndoBitmap;
    // rcupre la slection en cours
    CheckPluginFunc(GetSelBitmap(Bitmap));
    // applique le filtre
    SwapBitmap;
    // remplace la slection par le rsultat
    CheckPluginFunc(SetSelBitmap(Bitmap));
  finally
    EndFilter;
  end;
end;

// Parcourt l'image par triplet RGB
procedure TParamsForm.SwapBitmap;
var
  X, XM, Y, YM: Integer;
  P: PRGBTriple;
begin
  XM := Bitmap.Width - 1;
  YM := Bitmap.Height - 1;
  for Y := 0 to YM do
  begin
    P := Bitmap.ScanLine[Y];
    for X := 0 to XM do
    begin
      SwapRGB(P^, CheckSwap);
      Inc(P);
    end;
  end;
end;

// Swap chaque triplet
procedure TParamsForm.SwapRGB(var RGB: TRGBTriple; Index: Integer);
var
  R, G, B: Byte;
begin
  with RGB do
  begin
    // lcture des composantes
    R := rgbtRed;
    G := rgbtGreen;
    B := rgbtBlue;
    // modification des composantes
    case Index of
      0: // Swap to RBG
      begin
        rgbtRed := R;
        rgbtGreen := B;
        rgbtBlue := G;
      end;
      1: // Swap to GRB
      begin
        rgbtRed := G;
        rgbtGreen := R;
        rgbtBlue := B;
      end;
      2: // Swap to GBR
      begin
        rgbtRed := G;
        rgbtGreen := B;
        rgbtBlue := R;
      end;
      3: // Swap to BRG
      begin
        rgbtRed := B;
        rgbtGreen := R;
        rgbtBlue := G;
      end;
      else // Swap to BGR
      begin
        rgbtRed := B;
        rgbtGreen := G;
        rgbtBlue := R;
      end;
    end;
  end;
end;

// Recherche le swap  effectuer
function TParamsForm.CheckSwap: Integer;
begin
  if RdbRBG.Checked then Result := 0
  else if RdbGRB.Checked then Result := 1
  else if RdbGBR.Checked then Result := 2
  else if RdbBRG.Checked then Result := 3
  else Result := 4;
end;

// Signale le changement. Excute directement si aperu direct.
procedure TParamsForm.RdbClick(Sender: TObject);
begin
  Changed := True;
  if ChkPreview.Checked then DoPreview;
end;

// Dsactive le bouton Aperu
procedure TParamsForm.ChkPreviewClick(Sender: TObject);
begin
  BtnPreview.Enabled := not ChkPreview.Checked;
  if ChkPreview.Checked then DoPreview;
end;

// Aperu
procedure TParamsForm.BtnPreviewClick(Sender: TObject);
begin
  DoPreview;
end;

// Validation
procedure TParamsForm.BtnOkClick(Sender: TObject);
begin
  if Changed then DialogResult := DoPreview
  else DialogResult := True; // dj effectu par l'aperu
  Close;
end;

// Annulation
procedure TParamsForm.BtnCancelClick(Sender: TObject);
begin
  Close;
end;

// Actions via le clavier (KeyPreview  True)
procedure TParamsForm.FormKeyPress(Sender: TObject; var Key: Char);
begin
  if Key = #27 then Close
  else if Key = #13 then BtnOkClick(Sender);
end;

end.
